.. _api_dul_pduitems:

.. py:module:: pynetdicom.pdu_items

PDU Items and Sub-items (:mod:`pynetdicom.pdu_items`)
======================================================

.. currentmodule:: pynetdicom.pdu_items

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ApplicationContextItem
   PresentationContextItemRQ
   PresentationContextItemAC
   UserInformationItem
   AbstractSyntaxSubItem
   TransferSyntaxSubItem
   MaximumLengthSubItem
   ImplementationClassUIDSubItem
   ImplementationVersionNameSubItem
   SCP_SCU_RoleSelectionSubItem
   AsynchronousOperationsWindowSubItem
   UserIdentitySubItemRQ
   UserIdentitySubItemAC
   SOPClassExtendedNegotiationSubItem
   SOPClassCommonExtendedNegotiationSubItem
   PresentationDataValueItem

The encoding of DICOM Upper Layer PDU Items and Sub-items is always Big Endian
byte ordering.
